@@ -1,5 +1,6 @@
 from .ntypes import t_dependency, t_add, t_update, t_delete
 from .manager import Manager
+import pandas as pd
 
 
 class Dependency:
@@ -22,17 +23,17 @@ class Dependency:
 
     def currents(self, raw=False):
         json_data = self.manager.get_naas()
-        if raw:
-            json_filtered = []
-            for item in json_data:
-                if item["type"] == self.role and item["status"] != t_delete:
-                    print(item)
+        json_filtered = []
+        for item in json_data:
+            if item["type"] == self.role and item["status"] != t_delete:
+                if raw:
                     json_filtered.append(item)
-                return json_filtered
-        else:
-            for item in json_data:
-                if item["type"] == self.role and item["status"] != t_delete:
-                    print(f'File ==> {item["path"]}')
+                else:
+                    json_filtered.append({"path": item["path"]})
+        if raw is False:
+            df = pd.DataFrame(json_filtered)
+            return df
+        return json_filtered
 
     def add(self, path=None, debug=False):
         if self.manager.is_production():
@@ -57,7 +58,6 @@ class Dependency:
         )
         print("👌 Well done! Your Dependency has been sent to production. \n")
         print('PS: to remove the "Dependency" feature, just replace .add by .delete')
-        return self.manager.get_path(current_file)
 
     def delete(self, path=None, all=True, debug=False):
         if self.manager.is_production():
