@@ -9,6 +9,9 @@ import base64
 import json
 import uuid
 import os
+import sys
+import pydash as _
+from naas_drivers import naascredits
 
 
 class Notifications:
@@ -21,6 +24,15 @@ class Notifications:
         self.logger = logger
 
     def send(self, email_to, subject, html, files=[], email_from=None):
+        if not os.environ.get(
+            "JUPYTERHUB_API_TOKEN"
+        ) is None and "app.naas.ai" in os.environ.get("JUPYTERHUB_URL", ""):
+            if _.get(naascredits.connect().get_balance(), "balance") <= 0:
+                print(
+                    "🛑 You are out of credits and therefore cannot send notifications.",
+                    file=sys.stderr,
+                )
+                return
         uid = str(uuid.uuid4())
         soup = BeautifulSoup(html, features="html5lib")
         content = soup.get_text()
@@ -72,6 +84,15 @@ class Notifications:
         files=[],
         email_from=None,
     ):
+        if not os.environ.get(
+            "JUPYTERHUB_API_TOKEN"
+        ) is None and "app.naas.ai" in os.environ.get("JUPYTERHUB_URL", ""):
+            if _.get(naascredits.connect().get_balance(), "balance") <= 0:
+                print(
+                    "🛑 You are out of credits and therefore cannot send notifications.",
+                    file=sys.stderr,
+                )
+                return
         if n_env.notif_api is None:
             jsn = {"id": uid, "type": "notification error", "error": "not configured"}
             if self.logger is not None:
